"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.listIndexes = void 0;
const listIndexes = async params => {
  const {
    context,
    plugins,
    tenants: inputTenants,
    locales: inputLocales
  } = params;
  if (plugins.length === 0) {
    return [];
  }
  const indexes = [];
  const tenants = inputTenants || (await context.tenancy.listTenants());
  const initialTenant = context.tenancy.getCurrentTenant();
  try {
    for (const tenant of tenants) {
      context.tenancy.setCurrentTenant(tenant);
      let locales = inputLocales ? [...inputLocales] : [];
      if (locales.length === 0) {
        const [localesResult] = await context.i18n.locales.listLocales({
          limit: 10000
        });
        locales = localesResult;
      }
      for (const locale of locales) {
        for (const plugin of plugins) {
          const results = await plugin.getIndexList({
            context,
            tenant: tenant.id,
            locale: locale.code
          });
          for (const result of results) {
            if (indexes.some(i => i.index === result.index)) {
              continue;
            }
            indexes.push(result);
          }
        }
      }
    }
  } finally {
    context.tenancy.setCurrentTenant(initialTenant);
  }
  return indexes;
};
exports.listIndexes = listIndexes;

//# sourceMappingURL=listIndexes.js.map