"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ElasticsearchToDynamoDbSynchronization = void 0;
class ElasticsearchToDynamoDbSynchronization {
  constructor(params) {
    this.manager = params.manager;
    this.indexManager = params.indexManager;
    this.synchronize = params.synchronize;
    this.fetcher = params.fetcher;
  }
  async run(input) {
    const lastIndex = input.elasticsearchToDynamoDb?.index;
    let cursor = input.elasticsearchToDynamoDb?.cursor;
    const indexes = await this.fetchAllIndexes();
    let next = 0;
    if (lastIndex) {
      next = indexes.findIndex(index => index === lastIndex);
    }
    let currentIndex = indexes[next];
    while (currentIndex) {
      if (this.manager.isAborted()) {
        return this.manager.response.aborted();
      }
      /**
       * We will put 180 seconds because we are writing to the Elasticsearch/OpenSearch directly.
       * We want to leave enough time for possible retries.
       */
      //
      else if (this.manager.isCloseToTimeout(180)) {
        return this.manager.response.continue({
          ...input,
          elasticsearchToDynamoDb: {
            ...input.elasticsearchToDynamoDb,
            index: currentIndex,
            cursor
          }
        });
      }
      const result = await this.fetcher.fetch({
        index: currentIndex,
        cursor,
        limit: 100
      });
      const syncResult = await this.synchronize.execute({
        done: result.done,
        index: currentIndex,
        items: result.items
      });
      if (!syncResult.done && result.cursor) {
        cursor = result.cursor;
        continue;
      }
      cursor = undefined;
      const next = indexes.findIndex(index => index === currentIndex) + 1;
      currentIndex = indexes[next];
    }
    return this.manager.response.continue({
      ...input,
      elasticsearchToDynamoDb: {
        finished: true
      }
    });
  }
  async fetchAllIndexes() {
    const result = await this.indexManager.list();
    if (result.length > 0) {
      return result;
    }
    throw new Error("No Elasticsearch / OpenSearch indexes found.");
  }
}
exports.ElasticsearchToDynamoDbSynchronization = ElasticsearchToDynamoDbSynchronization;

//# sourceMappingURL=ElasticsearchToDynamoDbSynchronization.js.map